Enum DockerWorkspaceMountError
pub enum DockerWorkspaceMountError {
WorkspacePath {
path: String,
source: Error,
},
AllowedRoot {
path: String,
source: Error,
},
}Expand description
Canonicalization failures that the runtime layer can present through localized tool diagnostics without parsing an English error chain.
Variants