ensure_bootstrap_files

Function ensure_bootstrap_files 

pub async fn ensure_bootstrap_files(workspace_dir: &Path) -> Result<()>
Ensure that essential bootstrap files exist in the workspace directory.

When the workspace is created outside of zeroclaw onboard (e.g., non-tty daemon/cron sessions), these files would otherwise be missing. This function creates sensible defaults that allow the agent to operate with a basic identity.